<a name="readme-top"></a>
[![PyPI - Status](https://img.shields.io/pypi/status/gklr)](https://pypi.org/project/gklr/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/gklr)](https://pypi.org/project/gklr/)
[![PyPI-Server](https://img.shields.io/pypi/v/gklr.svg)](https://pypi.org/project/gklr/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/gklr.svg)](https://anaconda.org/conda-forge/gklr)
![Licence](https://img.shields.io/badge/Licence-MIT-blue)
[![Built Status](https://api.cirrus-ci.com/github/JoseAngelMartinB/gklr.svg?branch=main)](https://cirrus-ci.com/github/JoseAngelMartinB/gklr)
[![Coveralls](https://img.shields.io/coveralls/github/JoseAngelMartinB/gklr/main.svg)](https://coveralls.io/r/JoseAngelMartinB/gklr)

<!-- PROJECT LOGO -->
<br />
<div align="center">
  <!--
  <a href="https://github.com/JoseAngelMartinB/gklr">
    <img src="images/logo.png" alt="Logo" width="80" height="80">
  </a>
  -->

  <h3 align="center">GKLR</h3>

  <p align="center">
    Generalized Kernel Logistic Regression
    <br />
    <a href="https://gklr.joseangelmartin.com"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/JoseAngelMartinB/gklr/blob/main/notebooks/gklr_LPMC.ipynb">View Demo</a>
    ·
    <a href="https://github.com/JoseAngelMartinB/gklr/issues">Report Bug</a>
    ·
    <a href="https://github.com/JoseAngelMartinB/gklr/issues">Request Feature</a>
  </p>
</div>


## Description

Generalized Kernel Logistic Regression.

<p align="right">(<a href="#readme-top">back to top</a>)</p>


## Installation

It is possible to install the ``gklr`` package using ``pip``
```
pip install gklr
```

<p align="right">(<a href="#readme-top">back to top</a>)</p>


## Authors

GKLR was mainly developed by José Ángel Martín Baos from the University of
Castilla-La Mancha (JoseAngel.Martin@uclm.es). The main authors of this
package are listed in the [AUTHORS](AUTHORS.md) file.

<p align="right">(<a href="#readme-top">back to top</a>)</p>


## Known Issues
There are no known issues at this moment.

<p align="right">(<a href="#readme-top">back to top</a>)</p>


## License
GKLR is distributed under the MIT License. See `LICENSE` for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>
